// src/minio.ts
import { Client } from "minio";

// src/helpers/client-options.schema.ts
import { UrlSchema } from "@settlemint/sdk-utils/validation";
import { z } from "zod";
var ClientOptionsSchema = z.object({
  /** The URL of the MinIO instance to connect to */
  instance: UrlSchema
});
var ServerClientOptionsSchema = z.object({
  /** The URL of the MinIO instance to connect to */
  instance: UrlSchema,
  /** The MinIO access key used to authenticate with the MinIO server */
  accessKey: z.string(),
  /** The MinIO secret key used to authenticate with the MinIO server */
  secretKey: z.string()
});

// src/helpers/runtime.ts
function ensureServer() {
  if (typeof window !== "undefined") {
    throw new Error("This function can only be called on the server.");
  }
}

// src/minio.ts
function createServerMinioClient(options) {
  ensureServer();
  const validatedOptions = ServerClientOptionsSchema.parse(options);
  const url = new URL(validatedOptions.instance);
  return {
    client: new Client({
      endPoint: url.hostname,
      accessKey: validatedOptions.accessKey,
      secretKey: validatedOptions.secretKey,
      useSSL: url.protocol !== "http:",
      port: url.port ? Number(url.port) : void 0,
      region: "eu-central-1"
    })
  };
}
export {
  createServerMinioClient
};
//# sourceMappingURL=minio.mjs.map